@@ -1,4 +1,4 @@
-"""c3 user commands"""
+"""hyper user commands"""
 import typer
 from hypercli import C3
 from .output import output, spinner
@@ -13,7 +13,7 @@ def user_info(
 ):
     """Get current user info"""
     if ctx.invoked_subcommand is None:
-        c3 = C3()
+        client = C3()
         with spinner("Fetching user info..."):
-            user = c3.user.get()
+            user = client.user.get()
         output(user, fmt)
